@@ -18,22 +18,27 @@ from .utils import get_real_file_path, triple_or_double_tostring, APPLICATION_JS
 
 try:
     from requests_aws4auth import AWS4Auth
-except:
+except ImportError:
     AWS4Auth = None
+try:
+    from requests_ntlm import HttpNtlmAuth
+except ImportError:
+    HttpNtlmAuth = None
+
 try:
     import jstyleson as json
     from jsonschema import validate
-except:
+except ImportError:
     import json
-
     validate = None
+
 from textx import TextXSyntaxError, metamodel_from_file
 
 from .dsl_jsonparser import json_or_array_to_json
 from .exceptions import *
-from .parse_models import Allhttp, AuthWrap, DigestAuth, BasicAuth, Line, Query, Http, NameWrap, UrlWrap, Header, \
+from .parse_models import Allhttp, AuthWrap, DigestAuth, BasicAuth, Line, NtlmAuthWrap, Query, Http, NameWrap, UrlWrap, Header, \
     MultiPartFile, FilesWrap, TripleOrDouble, Payload as ParsePayload, Certificate, P12Certificate, ExtraArg, \
-    AWS_REGION_LIST, AWS_SERVICES_LIST, AwsAuthWrap, TestScript
+    AWS_REGION_LIST, AWS_SERVICES_LIST, AwsAuthWrap, TestScript, ScriptType
 from .property_schema import property_schema
 from .property_util import PropertyProvider
 
@@ -120,6 +125,7 @@ class HttpDef:
     allow_insecure = False
     session_clear = False
     test_script: str = ""
+    test_script_lang: ScriptType = ScriptType.JAVA_SCRIPT
 
     def get_har(self):
         if self.auth:
@@ -161,6 +167,7 @@ class HttpDef:
         payload = self.payload
         prep.prepare_body(data=payload.data, json=payload.json, files=payload.files)
         prep.prepare_auth(self.auth, self.url)
+        request_logger.info(f"auth configured is {self.auth}")
         # prep.prepare_hooks({"response": self.save_cookie_call_back})
         if payload.header and CONTENT_TYPE not in prep.headers:
             # if content-type is provided by header
@@ -257,6 +264,8 @@ class HttpDef:
                 auth_wrap = AuthWrap(basic_auth=BasicAuth(self.auth.username, self.auth.password))
             elif isinstance(self.auth, HTTPDigestAuth):
                 auth_wrap = AuthWrap(digest_auth=DigestAuth(self.auth.username, self.auth.password))
+            elif isinstance(self.auth, HttpNtlmAuth):
+                auth_wrap = AuthWrap(ntlm_auth=NtlmAuthWrap(self.auth.username, self.auth.password))
             elif isinstance(self.auth, AWS4Auth):
                 aws_auth: AWS4Auth = self.auth
                 auth_wrap = AuthWrap(
@@ -276,6 +285,8 @@ class HttpDef:
         if self.headers:
             for key, value in self.headers.items():
                 header_lines.append(Line(header=Header(key=key, value=value), query=None))
+        test_script = TestScript(self.test_script)
+        test_script.lang = self.test_script_lang
         return Http(
             namewrap=NameWrap(self.name),
             extra_args=extra_args,
@@ -283,7 +294,7 @@ class HttpDef:
             lines=header_lines + query_lines,
             payload=payload,
             certificate=certificate,
-            output=None, authwrap=auth_wrap, description=None, script_wrap=TestScript(self.test_script)
+            output=None, authwrap=auth_wrap, description=None, script_wrap=test_script
         )
 
 
@@ -693,7 +704,7 @@ class HttpDefBase(BaseModelProcessor):
             return sys.stdout
 
     def load_auth(self):
-        auth_wrap = self.get_current_or_base("authwrap")
+        auth_wrap:AuthWrap = self.get_current_or_base("authwrap")
         if auth_wrap:
             if basic_auth := auth_wrap.basic_auth:
                 self.httpdef.auth = HTTPBasicAuth(self.get_updated_content(basic_auth.username),
@@ -703,6 +714,9 @@ class HttpDefBase(BaseModelProcessor):
                 self.httpdef.auth = HTTPDigestAuth(self.get_updated_content(digest_auth.username),
                                                    self.get_updated_content(
                                                        digest_auth.password))
+            elif ntlm_auth := auth_wrap.ntlm_auth:
+                self.httpdef.auth = HttpNtlmAuth(self.get_updated_content(ntlm_auth.username), 
+                                                 self.get_updated_content(ntlm_auth.password))
             elif aws_auth_wrap := auth_wrap.aws_auth:
                 access_id = self.get_updated_content(aws_auth_wrap.access_id)
                 secret_token = self.get_updated_content(aws_auth_wrap.secret_token)
@@ -795,7 +809,7 @@ class HttpDefBase(BaseModelProcessor):
                     ## with current state, we are not support this use case
                     ## we may come back
                     ## all four parameters are required and are to be non empty
-                    raise DothttpAwsAuthException()
+                    raise DothttpAwsAuthException(access_id = access_id)
 
     def get_current_or_base(self, attr_key) -> Any:
         if getattr(self.http, attr_key):
@@ -821,9 +835,11 @@ class HttpDefBase(BaseModelProcessor):
 
     def load_test_script(self):
         self.httpdef.test_script = ""
-        if script_wrap := self.http.script_wrap:
+        script_wrap: TestScript = self.get_current_or_base("script_wrap")
+        if script_wrap and script_wrap.script:
             script = script_wrap.script[4:-2]
             self.httpdef.test_script = script.strip()
+            self.httpdef.test_script_lang = ScriptType.get_script_type(script_type=script_wrap.lang)
 
     def load_output(self):
         if self.http.output and self.http.output.output:
